##  Default Dashboard
To allow users to set their own default dashboards, in the Default Dashboard settings group, select the Allow users to set their own default dashboard checkbox.
To set a default dashboard for the workspace, select it from the list. Predefined dashboards can not be set as default.
